import React, { useState, useCallback, useEffect } from 'react';
import ReactDOM from 'react-dom';
import { scaleSqrt, max } from 'd3';
import { useWorldAtlas } from './useWorldAtlas';
import { useCountries } from './useCountries';
import { Marks } from './Marks';
import { Dropdown } from './Dropdown';
import { yearAttributes, countryAttributes } from './DropdownAttr';

const width = 960;
const height = 500;

const App = () => {
  const initialYear = 'Last available';
  var [year, setYear] = useState(initialYear);
  // console.log(year);

  var [country, setCountry] = useState(null);

  if (year == 'Last available') {
    year = 'Last available';
  } else {
    year = +year;
  }

  const worldAtlas = useWorldAtlas();
  const countries = useCountries();

  if (!worldAtlas || !countries) {
    return <pre>Loading...</pre>;
  }

  const sizeValue = d => d[year];
  const maxRadius = 30;

  const tooltipFormat = d =>
    d['Countries'] + '\n' + 'Year: ' + year + '\n' + 'Suicide: ' + d[year];

  const sizeScale = scaleSqrt()
    .domain([0, max(countries, sizeValue)])
    .range([0, maxRadius]);

  return (
    <>
      <div className="menus-container">
        <span className="dropdown-label">Year:</span>
        <Dropdown
          options={yearAttributes}
          id="x-select"
          value={year}
          onSelectedValueChange={setYear}
          // onChange={({ value }) => setXAttribute(value)}
        />
      </div>

      <div className="menus-container">
        <span className="dropdown-label">Countries:</span>
        <Dropdown
          options={countryAttributes}
          id="x-select"
          value={country}
          onSelectedValueChange={setCountry}
          // onChange={({ value }) => setXAttribute(value)}
        />
      </div>

      <svg width={width} height={height}>
        <Marks
          worldAtlas={worldAtlas}
          countries={countries}
          sizeScale={sizeScale}
          sizeValue={sizeValue}
          tooltipFormat={tooltipFormat}
          highlightCountry={country}
        />
      </svg>
    </>
  );
};
const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
